[Bf-blender-cvs] [64ade99] master: Freestyle: Python API documentation updates.

Tamito Kajiyama noreply at git.blender.org
Fri Sep 19 06:42:19 CEST 2014


Commit: 64ade99ecc0e9bd10332c90ae0f49cbc942443a7
Author: Tamito Kajiyama
Date:   Fri Sep 19 13:22:20 2014 +0900
Branches: master
https://developer.blender.org/rB64ade99ecc0e9bd10332c90ae0f49cbc942443a7

Freestyle: Python API documentation updates.

Fixed dead references of API identifiers (e.g., freestyle.types.Interface0D)
due to relocations of the identifiers into submodules.  Also made various minor
revisions of mark-ups and typos.

===================================================================

M	release/scripts/freestyle/modules/freestyle/chainingiterators.py
M	release/scripts/freestyle/modules/freestyle/functions.py
M	source/blender/freestyle/intern/python/BPy_FrsMaterial.cpp
M	source/blender/freestyle/intern/python/BPy_Interface0D.cpp
M	source/blender/freestyle/intern/python/BPy_Operators.cpp
M	source/blender/freestyle/intern/python/BPy_StrokeAttribute.cpp
M	source/blender/freestyle/intern/python/BinaryPredicate1D/BPy_FalseBP1D.cpp
M	source/blender/freestyle/intern/python/BinaryPredicate1D/BPy_Length2DBP1D.cpp
M	source/blender/freestyle/intern/python/BinaryPredicate1D/BPy_SameShapeIdBP1D.cpp
M	source/blender/freestyle/intern/python/BinaryPredicate1D/BPy_TrueBP1D.cpp
M	source/blender/freestyle/intern/python/BinaryPredicate1D/BPy_ViewMapGradientNormBP1D.cpp
M	source/blender/freestyle/intern/python/Interface0D/CurvePoint/BPy_StrokeVertex.cpp
M	source/blender/freestyle/intern/python/Iterator/BPy_ChainPredicateIterator.cpp
M	source/blender/freestyle/intern/python/Iterator/BPy_ChainSilhouetteIterator.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_BackboneStretcherShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_BezierCurveShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_BlenderTextureShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_CalligraphicShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_ColorNoiseShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_ColorVariationPatternShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_ConstantColorShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_ConstantThicknessShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_ConstrainedIncreasingThicknessShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_GuidingLinesShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_IncreasingColorShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_IncreasingThicknessShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_PolygonalizationShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_SamplingShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_SmoothingShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_SpatialNoiseShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_StrokeTextureShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_StrokeTextureStepShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_TextureAssignerShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_ThicknessNoiseShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_ThicknessVariationPatternShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_TipRemoverShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_fstreamShader.cpp
M	source/blender/freestyle/intern/python/StrokeShader/BPy_streamShader.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_Id/BPy_ShapeIdF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_Material/BPy_MaterialF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_Nature_EdgeNature/BPy_CurveNatureF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_Vec2f/BPy_Normal2DF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_Vec2f/BPy_VertexOrientation2DF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_Vec3f/BPy_VertexOrientation3DF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_ViewShape/BPy_GetOccludeeF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_ViewShape/BPy_GetShapeF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_double/BPy_Curvature2DAngleF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_double/BPy_DensityF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_double/BPy_GetProjectedXF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_double/BPy_GetProjectedYF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_double/BPy_GetProjectedZF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_double/BPy_GetXF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_double/BPy_GetYF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_double/BPy_GetZF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_double/BPy_LocalAverageDepthF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_double/BPy_ZDiscontinuityF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_float/BPy_GetCurvilinearAbscissaF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_float/BPy_GetParameterF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_float/BPy_GetViewMapGradientNormF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_float/BPy_ReadCompleteViewMapPixelF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_float/BPy_ReadMapPixelF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_float/BPy_ReadSteerableViewMapPixelF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_unsigned_int/BPy_QuantitativeInvisibilityF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction0D/UnaryFunction0D_vector_ViewShape/BPy_GetOccludersF0D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_Nature_EdgeNature/BPy_CurveNatureF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_Vec2f/BPy_Normal2DF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_Vec2f/BPy_Orientation2DF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_Vec3f/BPy_Orientation3DF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_Curvature2DAngleF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_DensityF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_GetCompleteViewMapDensityF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_GetDirectionalViewMapDensityF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_GetProjectedXF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_GetProjectedYF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_GetProjectedZF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_GetSteerableViewMapDensityF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_GetViewMapGradientNormF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_GetXF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_GetYF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_GetZF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_LocalAverageDepthF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_double/BPy_ZDiscontinuityF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_unsigned_int/BPy_QuantitativeInvisibilityF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_vector_ViewShape/BPy_GetOccludeeF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_vector_ViewShape/BPy_GetOccludersF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_vector_ViewShape/BPy_GetShapeF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_void/BPy_ChainingTimeStampF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_void/BPy_IncrementChainingTimeStampF1D.cpp
M	source/blender/freestyle/intern/python/UnaryFunction1D/UnaryFunction1D_void/BPy_TimeStampF1D.cpp
M	source/blender/freestyle/intern/python/UnaryPredicate0D/BPy_FalseUP0D.cpp
M	source/blender/freestyle/intern/python/UnaryPredicate0D/BPy_TrueUP0D.cpp
M	source/blender/freestyle/intern/python/UnaryPredicate1D/BPy_ContourUP1D.cpp
M	source/blender/freestyle/intern/python/UnaryPredicate1D/BPy_DensityLowerThanUP1D.cpp
M	source/blender/freestyle/intern/python/UnaryPredicate1D/BPy_EqualToChainingTimeStampUP1D.cpp
M	source/blender/freestyle/intern/python/UnaryPredicate1D/BPy_EqualToTimeStampUP1D.cpp
M	source/blender/freestyle/intern/python/UnaryPredicate1D/BPy_ExternalContourUP1D.cpp
M	source/blender/freestyle/intern/python/UnaryPredicate1D/BPy_FalseUP1D.cpp
M	source/blender/freestyle/intern/python/UnaryPredicate1D/BPy_QuantitativeInvisibilityUP1D.cpp
M	source/blender/freestyle/intern/python/UnaryPredicate1D/BPy_ShapeUP1D.cpp
M	source/blender/freestyle/intern/python/UnaryPredicate1D/BPy_TrueUP1D.cpp
M	source/blender/freestyle/intern/python/UnaryPredicate1D/BPy_WithinImageBoundaryUP1D.cpp

===================================================================

diff --git a/release/scripts/freestyle/modules/freestyle/functions.py b/release/scripts/freestyle/modules/freestyle/functions.py
index 8ad7e74..48d9b2e 100644
--- a/release/scripts/freestyle/modules/freestyle/functions.py
+++ b/release/scripts/freestyle/modules/freestyle/functions.py
@@ -237,10 +237,15 @@ class pyDensityAnisotropyF0D(UnaryFunction0DDouble):
 
 
 class pyViewMapGradientVectorF0D(UnaryFunction0DVec2f):
-    """Returns the gradient vector for a pixel.
+    """
+    Returns the gradient vector for a pixel.
+
+    .. method:: __init__(self, level)
+
+       Builds a pyViewMapGradientVectorF0D object.
 
-    :arg level: the level at which to compute the gradient
-    :type level: int
+       :arg level: the level at which to compute the gradient
+       :type level: int
     """
     def __init__(self, level):
         UnaryFunction0DVec2f.__init__(self)
diff --git a/source/blender/freestyle/intern/python/BPy_FrsMaterial.cpp b/source/blender/freestyle/intern/python/BPy_FrsMaterial.cpp
index 15cc4c3..4d0d140 100644
--- a/source/blender/freestyle/intern/python/BPy_FrsMaterial.cpp
+++ b/source/blender/freestyle/intern/python/BPy_FrsMaterial.cpp
@@ -80,9 +80,9 @@ PyDoc_STRVAR(FrsMaterial_doc,
 "   :arg emission: The emissive color.\n"
 "   :type emission: :class:`mathutils.Vector`, list or tuple of 4 float values\n"
 "   :arg shininess: The shininess coefficient.\n"
-"   :type shininess: :class:float\n"
+"   :type shininess: float\n"
 "   :arg priority: The line color priority.\n"
-"   :type priority: :class:int");
+"   :type priority: int");
 
 static int FrsMaterial_init(BPy_FrsMaterial *self, PyObject *args, PyObject *kwds)
 {
@@ -311,7 +311,7 @@ void FrsMaterial_mathutils_register_callback()
 PyDoc_STRVAR(FrsMaterial_line_doc,
 "RGBA components of the line color of the material.\n"
 "\n"
-":type: mathutils.Vector");
+":typ

@@ Diff output truncated at 10240 characters. @@




More information about the Bf-blender-cvs mailing list
diff --git a/release/scripts/freestyle/modules/freestyle/chainingiterators.py b/release/scripts/freestyle/modules/freestyle/chainingiterators.py
index 90523f9..52f22b3 100644
--- a/release/scripts/freestyle/modules/freestyle/chainingiterators.py
+++ b/release/scripts/freestyle/modules/freestyle/chainingiterators.py
@@ -82,12 +82,11 @@ def nature_in_preceding(nature, index):
 
 
 class pyChainSilhouetteIterator(ChainingIterator):
-    """Natural chaining iterator
-
-    Follows the edges of the same nature following the topology of
-    objects, with decreasing priority for silhouettes, then borders,
-    then suggestive contours, then all other edge types.  A ViewEdge
-    is only chained once.
+    """
+    Natural chaining iterator that follows the edges of the same nature
+    following the topology of objects, with decreasing priority for
+    silhouettes, then borders, then suggestive contours, then all other edge
+    types.  A ViewEdge is only chained once.
     """
     def __init__(self, stayInSelection=True):
         ChainingIterator.__init__(self, stayInSelection, True, None, True)
@@ -121,16 +120,20 @@ class pyChainSilhouetteIterator(ChainingIterator):
 
 
 class pyChainSilhouetteGenericIterator(ChainingIterator):
-    """Natural chaining iterator
+    """
+    Natural chaining iterator that follows the edges of the same nature
+    following the topology of objects, with decreasing priority for
+    silhouettes, then borders, then suggestive contours, then all other
+    edge types.
 
-    Follows the edges of the same nature following the topology of
-    objects, with decreasing priority for silhouettes, then borders,
-    then suggestive contours, then all other edge types.
+    .. method:: __init__(self, stayInSelection=True, stayInUnvisited=True)
 
-    :arg stayInSelection: True if it is allowed to go out of the selection
-    :type stayInSelection: bool
-    :arg stayInUnvisited: May the same ViewEdge be chained twice
-    :type stayInUnvisited: bool
+       Builds a pyChainSilhouetteGenericIterator object.
+
+       :arg stayInSelection: True if it is allowed to go out of the selection
+       :type stayInSelection: bool
+       :arg stayInUnvisited: May the same ViewEdge be chained twice
+       :type stayInUnvisited: bool
     """
 
     def __init__(self, stayInSelection=True, stayInUnvisited=True):
@@ -209,14 +212,18 @@ class pyExternalContourChainingIterator(ChainingIterator):
 
 
 class pySketchyChainSilhouetteIterator(ChainingIterator):
-    """Natural chaining iterator with a sketchy multiple touch
+    """
+    Natural chaining iterator with a sketchy multiple touch.  It chains the
+    same ViewEdge multiple times to achieve a sketchy effect.
+
+    .. method:: __init__(self, nRounds=3,stayInSelection=True)
 
-    Chains the same ViewEdge multiple times to achieve a sketchy effect.
+       Builds a pySketchyChainSilhouetteIterator object.
 
-    :arg rounds: Number of times every Viewedge is chained.
-    :type rounds: int
-    :arg stayInSelection: if False, edges outside of the selection can be chained.
-    :type stayInSelection: bool
+       :arg nRounds: Number of times every Viewedge is chained.
+       :type nRounds: int
+       :arg stayInSelection: if False, edges outside of the selection can be chained.
+       :type stayInSelection: bool
     """
 
     def __init__(self, nRounds=3,stayInSelection=True):
@@ -267,10 +274,10 @@ class pySketchyChainSilhouetteIterator(ChainingIterator):
 
 
 class pySketchyChainingIterator(ChainingIterator):
-    """Chaining iterator designed for sketchy style
-
-    It chaines the same ViewEdge several times in order to produce
-    multiple strokes per ViewEdge.
+    """
+    Chaining iterator designed for sketchy style.  It chaines the same
+    ViewEdge several times in order to produce multiple strokes per
+    ViewEdge.
     """
     def __init__(self, nRounds=3, stayInSelection=True):
         ChainingIterator.__init__(self, stayInSelection, False, None, True)
@@ -306,11 +313,16 @@ class pySketchyChainingIterator(ChainingIterator):
 
 
 class pyFillOcclusionsRelativeChainingIterator(ChainingIterator):
-    """Chaining iterator that fills small occlusions
+    """
+    Chaining iterator that fills small occlusions
+
+    .. method:: __init__(self, percent)
+
+       Builds a pyFillOcclusionsRelativeChainingIterator object.
 
-    :arg percent: The maximul length of the occluded part, expressed
-        in a percentage of the total chain length.
-    :type percent: float
+       :arg percent: The maximul length of the occluded part, expressed
+           in a percentage of the total chain length.
+       :type percent: float
     """
 
     def __init__(self, percent):
@@ -374,10 +386,15 @@ class pyFillOcclusionsRelativeChainingIterator(ChainingIterator):
 
 
 class pyFillOcclusionsAbsoluteChainingIterator(ChainingIterator):
-    """Chaining iterator that fills small occlusions
+    """
+    Chaining iterator that fills small occlusions
+
+    .. method:: __init__(self, length)
+
+       Builds a pyFillOcclusionsAbsoluteChainingIterator object.
 
-    :arg size: The maximum length of the occluded part in pixels.
-    :type size: int
+       :arg length: The maximum length of the occluded part in pixels.
+       :type length: int
     """
     def __init__(self, length):
         ChainingIterator.__init__(self, False, True, None, True)
@@ -429,12 +446,19 @@ class pyFillOcclusionsAbsoluteChainingIterator(ChainingIterator):
 
 
 class pyFillOcclusionsAbsoluteAndRelativeChainingIterator(ChainingIterator):
-    """Chaining iterator that fills small occlusions regardless of the
-    selection
+    """
+    Chaining iterator that fills small occlusions regardless of the
+    selection.
+
+    .. method:: __init__(self, percent, l)
+
+       Builds a pyFillOcclusionsAbsoluteAndRelativeChainingIterator object.
 
-    :arg percent: The maximul length of the occluded part as a
-        percentage of the total chain length.
-    :type percent: float
+       :arg percent: The maximul length of the occluded part as a
+           percentage of the total chain length.
+       :type percent: float
+       :arg l: Absolute length.
+       :type l: float
     """
     def __init__(self, percent, l):
         ChainingIterator.__init__(self, False, True, None, True)
@@ -492,12 +516,19 @@ class pyFillOcclusionsAbsoluteAndRelativeChainingIterator(ChainingIterator):
 
 
 class pyFillQi0AbsoluteAndRelativeChainingIterator(ChainingIterator):
-    """Chaining iterator that fills small occlusions regardless of the
-    selection
+    """
+    Chaining iterator that fills small occlusions regardless of the
+    selection.
+
+    .. method:: __init__(self, percent, l)
+
+       Builds a pyFillQi0AbsoluteAndRelativeChainingIterator object.
 
-    :arg percent: The maximul length of the occluded part as a
-        percentage of the total chain length.
-    :type percent: float
+       :arg percent: The maximul length of the occluded part as a
+           percentage of the total chain length.
+       :type percent: float
+       :arg l: Absolute length.
+       :type l: float
     """
     def __init__(self, percent, l):
         ChainingIterator.__init__(self, False, True, None, True)
@@ -554,15 +585,18 @@ class pyFillQi0AbsoluteAndRelativeChainingIterator(ChainingIterator):
 
 
 class pyNoIdChainSilhouetteIterator(ChainingIterator):
-    """Natural chaining iterator
+    """
+    Natural chaining iterator that follows the edges of the same nature
+    following the topology of objects, with decreasing priority for
+    silhouettes, then borders, then suggestive contours, then all other edge
+    types.  It won't chain the same ViewEdge twice.
+
+    .. method:: __init__(self, stayInSelection=True)
 
-    Follows the edges of the same nature following the topology of
-    objects, with decreasing priority for silhouettes, then borders,
-    then suggestive contours, then all other edge types.  It won't
-    chain the same ViewEdge twice.
+       Builds a pyNoIdChainSilhouetteIterator object.
 
-    :arg stayInSelection: True if it is allowed to go out of the selection
-    :type stayInSelection: bool
+       :arg stayInSelection: True if it is allowed to go out of the selection
+       :type stayInSelection: bool
     """
 
     def __init__(self, stayInSelection=True):